@@ -5,6 +5,7 @@ from uuid import UUID
 from briefcase.commands import (
     BuildCommand,
     CreateCommand,
+    OpenCommand,
     PackageCommand,
     PublishCommand,
     RunCommand,
@@ -28,6 +29,9 @@ class iOSXcodePassiveMixin(iOSMixin):
     def default_packaging_format(self):
         return "ipa"
 
+    def project_path(self, app):
+        return self.bundle_path(app) / f"{app.formal_name}.xcodeproj"
+
     def binary_path(self, app):
         return (
             self.bundle_path(app)
@@ -81,7 +85,7 @@ class iOSXcodeMixin(iOSXcodePassiveMixin):
         :returns: A tuple containing the udid, iOS version, and device name
             for the selected device.
         """
-        simulators = self.get_simulators(self, "iOS")
+        simulators = self.get_simulators(self.tools, "iOS")
 
         try:
             # Try to convert to a UDID. If this succeeds, then the argument
@@ -204,11 +208,28 @@ or:
 class iOSXcodeCreateCommand(iOSXcodePassiveMixin, CreateCommand):
     description = "Create and populate a iOS Xcode project."
 
+    def _extra_pip_args(self, app: BaseConfig):
+        """Any additional arguments that must be passed to pip when installing
+        packages.
 
-class iOSXcodeUpdateCommand(iOSXcodePassiveMixin, UpdateCommand):
+        :param app: The app configuration
+        :returns: A list of additional arguments
+        """
+        return [
+            "--prefer-binary",
+            "--extra-index-url",
+            "https://pypi.anaconda.org/beeware/simple",
+        ]
+
+
+class iOSXcodeUpdateCommand(iOSXcodeCreateCommand, UpdateCommand):
     description = "Update an existing iOS Xcode project."
 
 
+class iOSXcodeOpenCommand(iOSXcodePassiveMixin, OpenCommand):
+    description = "Open an existing iOS Xcode project."
+
+
 class iOSXcodeBuildCommand(iOSXcodeMixin, BuildCommand):
     description = "Build an iOS Xcode project."
 
@@ -234,18 +255,18 @@ class iOSXcodeBuildCommand(iOSXcodeMixin, BuildCommand):
         self.logger.info("Building XCode project...", prefix=app.app_name)
         with self.input.wait_bar("Building..."):
             try:
-                self.subprocess.run(
+                self.tools.subprocess.run(
                     [
                         "xcodebuild",
                         "-project",
-                        self.bundle_path(app) / f"{app.formal_name}.xcodeproj",
+                        self.project_path(app),
                         "-destination",
                         f'platform="iOS Simulator,name={device},OS={iOS_version}"',
                         "-quiet",
                         "-configuration",
                         "Debug",
                         "-arch",
-                        self.host_arch,
+                        self.tools.host_arch,
                         "-sdk",
                         "iphonesimulator",
                         "build",
@@ -294,19 +315,22 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
         # The simulator needs to be booted before being started.
         # If it's shut down, we can boot it again; but if it's currently
         # shutting down, we need to wait for it to shut down before restarting.
-        device_state = self.get_device_state(self, udid)
+        device_state = self.get_device_state(self.tools, udid)
         if device_state not in {DeviceState.SHUTDOWN, DeviceState.BOOTED}:
             with self.input.wait_bar("Waiting for simulator shutdown..."):
                 while device_state not in {DeviceState.SHUTDOWN, DeviceState.BOOTED}:
                     self.sleep(2)
-                    device_state = self.get_device_state(self, udid)
+                    device_state = self.get_device_state(self.tools, udid)
 
         # We now know the simulator is either shut down or booted;
         # if it's shut down, start it again.
         if device_state == DeviceState.SHUTDOWN:
             try:
                 with self.input.wait_bar("Booting simulator..."):
-                    self.subprocess.run(["xcrun", "simctl", "boot", udid], check=True)
+                    self.tools.subprocess.run(
+                        ["xcrun", "simctl", "boot", udid],
+                        check=True,
+                    )
             except subprocess.CalledProcessError as e:
                 raise BriefcaseCommandError(
                     f"Unable to boot {device} simulator running {iOS_version}"
@@ -315,7 +339,7 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
         # We now know the simulator is *running*, so we can open it.
         try:
             with self.input.wait_bar("Opening simulator..."):
-                self.subprocess.run(
+                self.tools.subprocess.run(
                     ["open", "-a", "Simulator", "--args", "-CurrentDeviceUDID", udid],
                     check=True,
                 )
@@ -330,8 +354,9 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
         try:
             self.logger.info("Installing app...", prefix=app.app_name)
             with self.input.wait_bar("Uninstalling any existing app version..."):
-                self.subprocess.run(
-                    ["xcrun", "simctl", "uninstall", udid, app_identifier], check=True
+                self.tools.subprocess.run(
+                    ["xcrun", "simctl", "uninstall", udid, app_identifier],
+                    check=True,
                 )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -341,7 +366,7 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
         # Install the app.
         try:
             with self.input.wait_bar("Installing new app version..."):
-                self.subprocess.run(
+                self.tools.subprocess.run(
                     ["xcrun", "simctl", "install", udid, self.binary_path(app)],
                     check=True,
                 )
@@ -351,7 +376,20 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
             ) from e
 
         # Start log stream for the app.
-        simulator_log_popen = self.subprocess.Popen(
+        # The following sets up a log stream filter that looks for:
+        #  1. a log sender that matches that app binary; or,
+        #  2. a log sender of that is a Python extension module,
+        #     and a process that matches the app binary.
+        # Case (1) works when the standard library is statically linked,
+        #   and for native NSLog() calls in the bootstrap binary
+        # Case (2) works when the standard library is dynamically linked,
+        #   and ctypes (which handles the NSLog integration) is an
+        #   extension module.
+        # It's not enough to filter on *just* the processImagePath,
+        # as the process will generate lots of system-level messages.
+        # We can't filter on *just* the senderImagePath, because other
+        # apps will generate log messages that would be caught by the filter.
+        simulator_log_popen = self.tools.subprocess.Popen(
             [
                 "xcrun",
                 "simctl",
@@ -362,7 +400,9 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
                 "--style",
                 "compact",
                 "--predicate",
-                f'senderImagePath ENDSWITH "/{app.formal_name}"',
+                f'senderImagePath ENDSWITH "/{app.formal_name}"'
+                f' OR (processImagePath ENDSWITH "/{app.formal_name}"'
+                ' AND senderImagePath ENDSWITH "-iphonesimulator.so")',
             ],
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
@@ -374,21 +414,26 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
 
         try:
             self.logger.info("Starting app...", prefix=app.app_name)
-            with self.input.wait_bar("Launching app..."):
-                self.subprocess.run(
-                    ["xcrun", "simctl", "launch", udid, app_identifier], check=True
-                )
-        except subprocess.CalledProcessError as e:
-            self.subprocess.cleanup("log stream", simulator_log_popen)
-            raise BriefcaseCommandError(f"Unable to launch app {app.app_name}.") from e
+            try:
+                with self.input.wait_bar("Launching app..."):
+                    self.tools.subprocess.run(
+                        ["xcrun", "simctl", "launch", udid, app_identifier],
+                        check=True,
+                    )
+            except subprocess.CalledProcessError as e:
+                raise BriefcaseCommandError(
+                    f"Unable to launch app {app.app_name}."
+                ) from e
 
-        # Start streaming logs for the app.
-        self.logger.info(
-            "Following simulator log output (type CTRL-C to stop log)...",
-            prefix=app.app_name,
-        )
-        self.logger.info("=" * 75)
-        self.subprocess.stream_output("log stream", simulator_log_popen)
+            # Start streaming logs for the app.
+            self.logger.info(
+                "Following simulator log output (type CTRL-C to stop log)...",
+                prefix=app.app_name,
+            )
+            self.logger.info("=" * 75)
+            self.tools.subprocess.stream_output("log stream", simulator_log_popen)
+        finally:
+            self.tools.subprocess.cleanup("log stream", simulator_log_popen)
 
         # Preserve the device selection as state.
         return {"udid": udid}
@@ -407,6 +452,7 @@ class iOSXcodePublishCommand(iOSXcodeMixin, PublishCommand):
 # Declare the briefcase command bindings
 create = iOSXcodeCreateCommand  # noqa
 update = iOSXcodeUpdateCommand  # noqa
+open = iOSXcodeOpenCommand  # noqa
 build = iOSXcodeBuildCommand  # noqa
 run = iOSXcodeRunCommand  # noqa
 package = iOSXcodePackageCommand  # noqa
