@@ -8,7 +8,12 @@ from requests import exceptions as requests_exceptions
 from briefcase.commands.create import InvalidSupportPackage, MissingSupportPackage
 from briefcase.exceptions import MissingNetworkResourceError, NetworkFailure
 
-from ...utils import create_zip_file, mock_file_download, mock_zip_download
+from ...utils import (
+    create_zip_file,
+    mock_file_download,
+    mock_tgz_download,
+    mock_zip_download,
+)
 
 
 def test_install_app_support_package(
@@ -20,31 +25,32 @@ def test_install_app_support_package(
 ):
     """A support package can be downloaded and unpacked where it is needed."""
 
-    # Mock download_url to return a support package
-    create_command.download_url = mock.MagicMock(
-        side_effect=mock_zip_download(
-            "Python-3.X-OS-support.zip",
+    # Mock download.file to return a support package
+    create_command.tools.download.file = mock.MagicMock(
+        side_effect=mock_tgz_download(
+            "Python-3.X-tester-support.b37.tar.gz",
             [("internal/file.txt", "hello world")],
         )
     )
 
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # Confirm the right URL was used
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=create_command.data_path / "support",
-        url="https://briefcase-support.org/python?platform=tester&version=3.X&arch=gothic",
+        url="https://briefcase-support.s3.amazonaws.com/python/3.X/tester/Python-3.X-tester-support.b37.tar.gz",
+        role="support package",
     )
 
     # Confirm the right file was unpacked
-    create_command.shutil.unpack_archive.assert_called_with(
-        tmp_path / "data" / "support" / "Python-3.X-OS-support.zip",
+    create_command.tools.shutil.unpack_archive.assert_called_with(
+        tmp_path / "data" / "support" / "Python-3.X-tester-support.b37.tar.gz",
         extract_dir=support_path,
     )
 
@@ -65,31 +71,32 @@ def test_install_pinned_app_support_package(
     # Pin the support revision
     myapp.support_revision = "42"
 
-    # Mock download_url to return a support package
-    create_command.download_url = mock.MagicMock(
-        side_effect=mock_zip_download(
-            "Python-3.X-OS-support.zip",
+    # Mock download.file to return a support package
+    create_command.tools.download.file = mock.MagicMock(
+        side_effect=mock_tgz_download(
+            "Python-3.X-tester-support.b42.tar.gz",
             [("internal/file.txt", "hello world")],
         )
     )
 
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # Confirm the right URL was used
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=create_command.data_path / "support",
-        url="https://briefcase-support.org/python?platform=tester&version=3.X&arch=gothic&revision=42",
+        url="https://briefcase-support.s3.amazonaws.com/python/3.X/tester/Python-3.X-tester-support.b42.tar.gz",
+        role="support package",
     )
 
     # Confirm the right file was unpacked
-    create_command.shutil.unpack_archive.assert_called_with(
-        tmp_path / "data" / "support" / "Python-3.X-OS-support.zip",
+    create_command.tools.shutil.unpack_archive.assert_called_with(
+        tmp_path / "data" / "support" / "Python-3.X-tester-support.b42.tar.gz",
         extract_dir=support_path,
     )
 
@@ -115,23 +122,23 @@ def test_install_custom_app_support_package_file(
         [("internal/file.txt", "hello world")],
     )
 
-    # Modify download_url to return the temp zipfile
-    create_command.download_url = mock.MagicMock()
+    # Modify download.file to return the temp zipfile
+    create_command.tools.download.file = mock.MagicMock()
 
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # There should have been no download attempt,
     # as the resource is local.
-    create_command.download_url.assert_not_called()
+    create_command.tools.download.file.assert_not_called()
 
     # Confirm the right file was unpacked
-    create_command.shutil.unpack_archive.assert_called_with(
+    create_command.tools.shutil.unpack_archive.assert_called_with(
         support_file,
         extract_dir=support_path,
     )
@@ -141,6 +148,55 @@ def test_install_custom_app_support_package_file(
     assert (support_path / "internal" / "file.txt").exists()
 
 
+def test_install_custom_app_support_package_file_with_revision(
+    create_command,
+    myapp,
+    tmp_path,
+    support_path,
+    app_requirements_path_index,
+    capsys,
+):
+    """If a custom support package file also specifies a revision, the revision
+    is ignored with a warning."""
+    # Provide an app-specific override of the package URL
+    myapp.support_package = os.fsdecode(tmp_path / "custom" / "support.zip")
+    myapp.support_revision = "42"
+
+    # Write a temporary support zip file
+    support_file = create_zip_file(
+        tmp_path / "custom" / "support.zip",
+        [("internal/file.txt", "hello world")],
+    )
+
+    # Modify download.file to return the temp zipfile
+    create_command.tools.download.file = mock.MagicMock()
+
+    # Mock shutil so we can confirm that unpack is called,
+    # but we still want the side effect of calling it
+    create_command.tools.shutil = mock.MagicMock()
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
+
+    # Install the support package
+    create_command.install_app_support_package(myapp)
+
+    # There should have been no download attempt,
+    # as the resource is local.
+    create_command.tools.download.file.assert_not_called()
+
+    # Confirm the right file was unpacked
+    create_command.tools.shutil.unpack_archive.assert_called_with(
+        support_file,
+        extract_dir=support_path,
+    )
+
+    # Confirm that the full path to the support file
+    # has been unpacked.
+    assert (support_path / "internal" / "file.txt").exists()
+
+    # A warning about the support revision was generated.
+    assert "support revision will be ignored." in capsys.readouterr().out
+
+
 def test_support_package_url_with_invalid_custom_support_packge_url(
     create_command,
     myapp,
@@ -153,8 +209,8 @@ def test_support_package_url_with_invalid_custom_support_packge_url(
     url = "https://example.com/custom/support.zip"
     myapp.support_package = url
 
-    # Modify download_url to raise an exception
-    create_command.download_url = mock.MagicMock(
+    # Modify download.file to raise an exception
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=MissingNetworkResourceError(url)
     )
 
@@ -163,13 +219,14 @@ def test_support_package_url_with_invalid_custom_support_packge_url(
         create_command.install_app_support_package(myapp)
 
     # However, there will have been a download attempt
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=(
             create_command.data_path
             / "support"
             / "55441abbffa311f65622df45a943afc347a21ab40e8dcec79472c92ef467db24"
         ),
         url=url,
+        role="support package",
     )
 
 
@@ -179,13 +236,10 @@ def test_support_package_url_with_unsupported_platform(
     app_requirements_path_index,
 ):
     """An unsupported platform raises MissingSupportPackage."""
-    # Set the host architecture to something unsupported
-    create_command.host_arch = "unknown"
-
-    # Modify download_url to raise an exception due to missing support package
-    create_command.download_url = mock.MagicMock(
+    # Modify download.file to raise an exception due to missing support package
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=MissingNetworkResourceError(
-            "https://briefcase-support.org/python?platform=tester&version=3.X&arch=unknown"
+            url="https://briefcase-support.s3.amazonaws.com/python/3.X/tester/Python-3.X-tester-support.b37.tar.gz",
         )
     )
 
@@ -194,9 +248,10 @@ def test_support_package_url_with_unsupported_platform(
         create_command.install_app_support_package(myapp)
 
     # However, there will have been a download attempt
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=create_command.data_path / "support",
-        url="https://briefcase-support.org/python?platform=tester&version=3.X&arch=unknown",
+        url="https://briefcase-support.s3.amazonaws.com/python/3.X/tester/Python-3.X-tester-support.b37.tar.gz",
+        role="support package",
     )
 
 
@@ -211,8 +266,8 @@ def test_install_custom_app_support_package_url(
     # Provide an app-specific override of the package URL
     myapp.support_package = "https://example.com/custom/custom-support.zip"
 
-    # Mock download_url to return a support package
-    create_command.download_url = mock.MagicMock(
+    # Mock download.file to return a support package
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=mock_zip_download(
             "custom-support.zip",
             [("internal/file.txt", "hello world")],
@@ -221,24 +276,25 @@ def test_install_custom_app_support_package_url(
 
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # Confirm the right URL and download path was used
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=(
             create_command.data_path
             / "support"
             / "1d3ac0e09eb22abc63c4e7b699b6ab5d58e277015eeae61070e3f9f11512e6b3"
         ),
         url="https://example.com/custom/custom-support.zip",
+        role="support package",
     )
 
     # Confirm the right file was unpacked into the hashed location
-    create_command.shutil.unpack_archive.assert_called_with(
+    create_command.tools.shutil.unpack_archive.assert_called_with(
         tmp_path
         / "data"
         / "support"
@@ -252,23 +308,22 @@ def test_install_custom_app_support_package_url(
     assert (support_path / "internal" / "file.txt").exists()
 
 
-def test_install_pinned_custom_app_support_package_url(
+def test_install_custom_app_support_package_url_with_revision(
     create_command,
     myapp,
     tmp_path,
     support_path,
     app_requirements_path_index,
+    capsys,
 ):
-    """A custom support package can be specified as URL, and pinned to a
-    revision."""
-    # Pin the support revision
+    """If a custom support package URL also specifies a revision, the revision
+    is ignored with a warning."""
+    # Provide an app-specific override of the package URL and revision
+    myapp.support_package = "https://example.com/custom/custom-support.zip"
     myapp.support_revision = "42"
 
-    # Provide an app-specific override of the package URL
-    myapp.support_package = "https://example.com/custom/custom-support.zip"
-
-    # Mock download_url to return a support package
-    create_command.download_url = mock.MagicMock(
+    # Mock download.file to return a support package
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=mock_zip_download(
             "custom-support.zip",
             [("internal/file.txt", "hello world")],
@@ -277,28 +332,29 @@ def test_install_pinned_custom_app_support_package_url(
 
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # Confirm the right URL and download path was used
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=(
             create_command.data_path
             / "support"
-            / "6390bc0eb3eca03218604f6072094d44f44d82eacefc21975cc5b9b7b1720a0d"
+            / "1d3ac0e09eb22abc63c4e7b699b6ab5d58e277015eeae61070e3f9f11512e6b3"
         ),
-        url="https://example.com/custom/custom-support.zip?revision=42",
+        url="https://example.com/custom/custom-support.zip",
+        role="support package",
     )
 
-    # Confirm the right file was unpacked
-    create_command.shutil.unpack_archive.assert_called_with(
+    # Confirm the right file was unpacked into the hashed location
+    create_command.tools.shutil.unpack_archive.assert_called_with(
         tmp_path
         / "data"
         / "support"
-        / "6390bc0eb3eca03218604f6072094d44f44d82eacefc21975cc5b9b7b1720a0d"
+        / "1d3ac0e09eb22abc63c4e7b699b6ab5d58e277015eeae61070e3f9f11512e6b3"
         / "custom-support.zip",
         extract_dir=support_path,
     )
@@ -307,24 +363,23 @@ def test_install_pinned_custom_app_support_package_url(
     # has been unpacked.
     assert (support_path / "internal" / "file.txt").exists()
 
+    # A warning about the support revision was generated.
+    assert "support revision will be ignored." in capsys.readouterr().out
 
-def test_install_pinned_custom_app_support_package_url_with_args(
+
+def test_install_custom_app_support_package_url_with_args(
     create_command,
     myapp,
     tmp_path,
     support_path,
     app_requirements_path_index,
 ):
-    """A custom support package can be specified as URL with args, and pinned
-    to a revision."""
-    # Pin the support revision
-    myapp.support_revision = "42"
-
+    """A custom support package can be specified as URL with args."""
     # Provide an app-specific override of the package URL
     myapp.support_package = "https://example.com/custom/custom-support.zip?cool=Yes"
 
-    # Mock download_url to return a support package
-    create_command.download_url = mock.MagicMock(
+    # Mock download.file to return a support package
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=mock_zip_download(
             "custom-support.zip",
             [("internal/file.txt", "hello world")],
@@ -332,26 +387,27 @@ def test_install_pinned_custom_app_support_package_url_with_args(
     )
     # Mock shutil so we can confirm that unpack is called,
     # but we still want the side effect of calling it
-    create_command.shutil = mock.MagicMock()
-    create_command.shutil.unpack_archive.side_effect = shutil.unpack_archive
+    create_command.tools.shutil = mock.MagicMock(spec_set=shutil)
+    create_command.tools.shutil.unpack_archive.side_effect = shutil.unpack_archive
 
     # Install the support package
     create_command.install_app_support_package(myapp)
 
     # Confirm the right URL was used
-    create_command.download_url.assert_called_with(
+    create_command.tools.download.file.assert_called_with(
         download_path=create_command.data_path
         / "support"
-        / "1a7054ce49ce29aeec90591be2d69cd655bd5414f4a9017425026760a375847b",
-        url="https://example.com/custom/custom-support.zip?cool=Yes&revision=42",
+        / "f8cf64ad2ba249a1efbb63db60ebdc64f043035fbdd81934c6ad1e84a030c429",
+        url="https://example.com/custom/custom-support.zip?cool=Yes",
+        role="support package",
     )
 
     # Confirm the right file was unpacked
-    create_command.shutil.unpack_archive.assert_called_with(
+    create_command.tools.shutil.unpack_archive.assert_called_with(
         tmp_path
         / "data"
         / "support"
-        / "1a7054ce49ce29aeec90591be2d69cd655bd5414f4a9017425026760a375847b"
+        / "f8cf64ad2ba249a1efbb63db60ebdc64f043035fbdd81934c6ad1e84a030c429"
         / "custom-support.zip",
         extract_dir=support_path,
     )
@@ -368,7 +424,7 @@ def test_offline_install(
     app_requirements_path_index,
 ):
     """If the computer is offline, an error is raised."""
-    create_command.download_url = mock.MagicMock(
+    create_command.tools.requests.get = mock.MagicMock(
         side_effect=requests_exceptions.ConnectionError
     )
 
@@ -385,8 +441,8 @@ def test_invalid_support_package(
     app_requirements_path_index,
 ):
     """If the support package isn't a valid zipfile, an error is raised."""
-    # Mock download_url to return a non-zip file
-    create_command.download_url = mock.MagicMock(
+    # Mock download.file to return a non-zip file
+    create_command.tools.download.file = mock.MagicMock(
         side_effect=mock_file_download(
             "not-a.zip",
             "This isn't a zip file",
@@ -418,6 +474,19 @@ def test_missing_support_package(
 def test_no_support_path(create_command, myapp, no_support_path_index):
     """If support_path is not listed in briefcase.toml, a support package will
     not be downloaded."""
-    create_command.download_url = mock.MagicMock()
+    create_command.tools.download.file = mock.MagicMock()
     create_command.install_app_support_package(myapp)
-    create_command.download_url.assert_not_called()
+    create_command.tools.download.file.assert_not_called()
+
+
+def test_no_support_revision(create_command, myapp, no_support_revision_index):
+    """If support_revision is not listed in briefcase.toml, a support package
+    will not be downloaded."""
+    create_command.tools.download.file = mock.MagicMock()
+
+    # An error is raised when attempting to install the support package
+    with pytest.raises(MissingSupportPackage):
+        create_command.install_app_support_package(myapp)
+
+    # No download attempt is made.
+    create_command.tools.download.file.assert_not_called()
