@@ -2,13 +2,14 @@ import pytest
 
 from briefcase.commands import DevCommand
 from briefcase.commands.base import full_options
+from briefcase.console import Console, Log
 from briefcase.exceptions import BriefcaseCommandError
 
 
 class DummyDevCommand(DevCommand):
     """A dummy Dev command that doesn't actually do anything.
 
-    It only serves to track which actions would be performend.
+    It only serves to track which actions would be performed.
     """
 
     platform = "tester"
@@ -16,7 +17,9 @@ class DummyDevCommand(DevCommand):
     description = "Dummy dev command"
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, apps=[], **kwargs)
+        kwargs.setdefault("logger", Log())
+        kwargs.setdefault("console", Console())
+        super().__init__(*args, apps={}, **kwargs)
 
         self.actions = []
         self.env = dict(a=1, b=2, c=3)
@@ -25,6 +28,10 @@ class DummyDevCommand(DevCommand):
         super().verify_tools()
         self.actions.append(("verify",))
 
+    def verify_app_tools(self, app):
+        super().verify_app_tools(app=app)
+        self.actions.append(("verify-app-tools", app.app_name))
+
     def install_dev_dependencies(self, app, **kwargs):
         self.actions.append(("dev_dependencies", app.app_name, kwargs))
 
@@ -58,6 +65,8 @@ def test_no_args_one_app(dev_command, first_app):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # Run the first app devly
         ("run_dev", "first", {}, dev_command.env),
     ]
@@ -102,6 +111,8 @@ def test_with_arg_one_app(dev_command, first_app):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # Run the first app devly
         ("run_dev", "first", {}, dev_command.env),
     ]
@@ -125,6 +136,8 @@ def test_with_arg_two_apps(dev_command, first_app, second_app):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "second"),
         # Run the second app devly
         ("run_dev", "second", {}, dev_command.env),
     ]
@@ -170,6 +183,8 @@ def test_update_dependencies(dev_command, first_app):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # An update was requested
         ("dev_dependencies", "first", {}),
         # Then, it will be started
@@ -194,6 +209,8 @@ def test_run_uninstalled(dev_command, first_app_uninstalled):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # The app will be installed
         ("dev_dependencies", "first", {}),
         # Then, it will be started
@@ -219,6 +236,8 @@ def test_update_uninstalled(dev_command, first_app_uninstalled):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # An update was requested
         ("dev_dependencies", "first", {}),
         # Then, it will be started
@@ -243,6 +262,8 @@ def test_no_run(dev_command, first_app_uninstalled):
     assert dev_command.actions == [
         # Tools are verified
         ("verify",),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
         # Only update dependencies without running the app
         ("dev_dependencies", "first", {}),
     ]
