@@ -9,7 +9,7 @@ from briefcase.exceptions import BriefcaseCommandError
 def test_subprocess_running_successfully(dev_command, first_app, tmp_path):
     env = dict(a=1, b=2, c=3)
     dev_command.run_dev_app(first_app, env)
-    dev_command.subprocess.run.assert_called_once_with(
+    dev_command.tools.subprocess.run.assert_called_once_with(
         [
             sys.executable,
             "-c",
@@ -20,19 +20,22 @@ def test_subprocess_running_successfully(dev_command, first_app, tmp_path):
             ),
         ],
         env=env,
-        cwd=dev_command.home_path,
+        cwd=dev_command.tools.home_path,
         check=True,
+        stream_output=True,
     )
 
 
 def test_subprocess_throws_error(dev_command, first_app, tmp_path):
     env = dict(a=1, b=2, c=3)
-    dev_command.subprocess.run.side_effect = CalledProcessError(returncode=2, cmd="cmd")
+    dev_command.tools.subprocess.run.side_effect = CalledProcessError(
+        returncode=2, cmd="cmd"
+    )
     with pytest.raises(
         BriefcaseCommandError, match="Unable to start application 'first'"
     ):
         dev_command.run_dev_app(first_app, env)
-    dev_command.subprocess.run.assert_called_once_with(
+    dev_command.tools.subprocess.run.assert_called_once_with(
         [
             sys.executable,
             "-c",
@@ -43,6 +46,7 @@ def test_subprocess_throws_error(dev_command, first_app, tmp_path):
             ),
         ],
         env=env,
-        cwd=dev_command.home_path,
+        cwd=dev_command.tools.home_path,
         check=True,
+        stream_output=True,
     )
