@@ -7,11 +7,11 @@ from briefcase.exceptions import BriefcaseCommandError, InvalidDeviceError
 from briefcase.integrations.android_sdk import ADB
 
 
-def test_install_apk(mock_sdk, capsys):
+def test_install_apk(mock_tools, capsys):
     """Invoking `install_apk()` calls `run()` with the appropriate
     parameters."""
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(return_value="example normal adb output")
 
     # Invoke install
@@ -25,10 +25,10 @@ def test_install_apk(mock_sdk, capsys):
     assert "normal adb output" not in capsys.readouterr()
 
 
-def test_install_failure(mock_sdk, capsys):
+def test_install_failure(mock_tools, capsys):
     """If `install_apk()` fails, an error is raised."""
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(
         side_effect=subprocess.CalledProcessError(returncode=2, cmd="install")
     )
@@ -41,10 +41,10 @@ def test_install_failure(mock_sdk, capsys):
     adb.run.assert_called_once_with("install", "-r", "example.apk")
 
 
-def test_invalid_device(mock_sdk, capsys):
+def test_invalid_device(mock_tools, capsys):
     """Invoking `install_apk()` on an invalid device raises an error."""
     # Mock out the run command on an adb instance
-    adb = ADB(mock_sdk, "exampleDevice")
+    adb = ADB(mock_tools, "exampleDevice")
     adb.run = MagicMock(side_effect=InvalidDeviceError("device", "exampleDevice"))
 
     # Invoke install
