@@ -2,7 +2,7 @@ import pytest
 
 
 @pytest.fixture
-def test_device(mock_sdk, tmp_path):
+def test_device(tmp_path):
     """Create an AVD configuration file."""
     config_file = (
         tmp_path / "home" / ".android" / "avd" / "testDevice.avd" / "config.ini"
@@ -30,10 +30,10 @@ disk.cachePartition.size=42M
     return config_file
 
 
-def test_update_existing(mock_sdk, test_device):
+def test_update_existing(android_sdk, test_device):
     """Existing keys in an Android AVD config can be updated."""
     # Update 2 keys in the config
-    mock_sdk.update_emulator_config(
+    android_sdk.update_emulator_config(
         "testDevice",
         {
             "avd.name": "testDevice",
@@ -59,10 +59,10 @@ disk.cachePartition.size=37MB
     )
 
 
-def test_new_content(mock_sdk, test_device):
+def test_new_content(android_sdk, test_device):
     """New keys can be added to an Android AVD config."""
     # Add 2 new keys to the config
-    mock_sdk.update_emulator_config(
+    android_sdk.update_emulator_config(
         "testDevice",
         {
             "skin.name": "pixel_3a",
