@@ -1,14 +1,30 @@
+import sys
+
 import pytest
 
+from briefcase.console import Console, Log
 from briefcase.platforms.android.gradle import GradleCreateCommand
 
 
 @pytest.fixture
 def create_command(tmp_path, first_app_config):
-    command = GradleCreateCommand(base_path=tmp_path / "base_path")
+    command = GradleCreateCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
     return command
 
 
+def test_support_package_filename(create_command):
+    """The Android support package filename has been customized."""
+    assert (
+        create_command.support_package_filename(52)
+        == f"Python-3.{sys.version_info.minor}-Android-support.b52.zip"
+    )
+
+
 @pytest.mark.parametrize(
     "version, build, version_code",
     [
@@ -46,5 +62,5 @@ def test_version_code(create_command, first_app_config, version, build, version_
         "version_code": version_code,
         "safe_formal_name": "First App",
     }
-    # Version code must be less than a 32 bit signed integer MAXINT.
+    # Version code must be less than a 32-bit signed integer MAXINT.
     assert int(version_code) < 2147483647
