@@ -1,12 +1,19 @@
+from briefcase.console import Console, Log
 from briefcase.platforms.iOS.xcode import iOSXcodeCreateCommand
 
 
 def test_binary_path(first_app_config, tmp_path):
-    command = iOSXcodeCreateCommand(base_path=tmp_path)
+    command = iOSXcodeCreateCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
     binary_path = command.binary_path(first_app_config)
 
     assert binary_path == (
         tmp_path
+        / "base_path"
         / "iOS"
         / "Xcode"
         / "First App"
@@ -17,11 +24,17 @@ def test_binary_path(first_app_config, tmp_path):
 
 
 def test_distribution_path(first_app_config, tmp_path):
-    command = iOSXcodeCreateCommand(base_path=tmp_path)
+    command = iOSXcodeCreateCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
     binary_path = command.binary_path(first_app_config)
 
     assert binary_path == (
         tmp_path
+        / "base_path"
         / "iOS"
         / "Xcode"
         / "First App"
