@@ -3,14 +3,21 @@ from unittest import mock
 
 import pytest
 
+from briefcase.console import Console, Log
 from briefcase.exceptions import BriefcaseCommandError
+from briefcase.integrations.subprocess import Subprocess
 from briefcase.integrations.xcode import DeviceState
 from briefcase.platforms.iOS.xcode import iOSXcodeRunCommand
 
 
 def test_run_app_simulator_booted(first_app_config, tmp_path):
     """An iOS App can be started when the simulator is already booted."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -20,15 +27,15 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
     # Simulator is already booted
     command.get_device_state = mock.MagicMock(return_value=DeviceState.BOOTED)
 
-    command.subprocess = mock.MagicMock()
-    log_stream_process = mock.MagicMock()
-    command.subprocess.Popen.return_value = log_stream_process
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
+    command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
     command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Open the simulator
             mock.call(
@@ -61,6 +68,7 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
                     "install",
                     "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D",
                     tmp_path
+                    / "base_path"
                     / "iOS"
                     / "Xcode"
                     / "First App"
@@ -84,7 +92,7 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup is triggered
-    command.subprocess.Popen.assert_called_with(
+    command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -95,21 +103,30 @@ def test_run_app_simulator_booted(first_app_config, tmp_path):
             "--style",
             "compact",
             "--predicate",
-            'senderImagePath ENDSWITH "/First App"',
+            'senderImagePath ENDSWITH "/First App"'
+            ' OR (processImagePath ENDSWITH "/First App"'
+            ' AND senderImagePath ENDSWITH "-iphonesimulator.so")',
         ],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.subprocess.stream_output.assert_called_with(
+    command.tools.subprocess.stream_output.assert_called_with(
+        "log stream", log_stream_process
+    )
+    command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
-    command.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_shut_down(first_app_config, tmp_path):
     """An iOS App can be started when the simulator is shut down."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -119,15 +136,15 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
     # Simulator is shut down
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
-    command.subprocess = mock.MagicMock()
-    log_stream_process = mock.MagicMock()
-    command.subprocess.Popen.return_value = log_stream_process
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
+    command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
     command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -165,6 +182,7 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
                     "install",
                     "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D",
                     tmp_path
+                    / "base_path"
                     / "iOS"
                     / "Xcode"
                     / "First App"
@@ -188,7 +206,7 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup is triggered
-    command.subprocess.Popen.assert_called_with(
+    command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -199,21 +217,30 @@ def test_run_app_simulator_shut_down(first_app_config, tmp_path):
             "--style",
             "compact",
             "--predicate",
-            'senderImagePath ENDSWITH "/First App"',
+            'senderImagePath ENDSWITH "/First App"'
+            ' OR (processImagePath ENDSWITH "/First App"'
+            ' AND senderImagePath ENDSWITH "-iphonesimulator.so")',
         ],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.subprocess.stream_output.assert_called_with(
+    command.tools.subprocess.stream_output.assert_called_with(
+        "log stream", log_stream_process
+    )
+    command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
-    command.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
     """An iOS App can be started when the simulator is shutting down."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -233,9 +260,9 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
     )
 
     command.sleep = mock.MagicMock()
-    command.subprocess = mock.MagicMock()
-    log_stream_process = mock.MagicMock()
-    command.subprocess.Popen.return_value = log_stream_process
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    log_stream_process = mock.MagicMock(spec_set=subprocess.Popen)
+    command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
     command.run_app(first_app_config)
@@ -244,7 +271,7 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
     assert command.sleep.call_count == 4
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -282,6 +309,7 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
                     "install",
                     "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D",
                     tmp_path
+                    / "base_path"
                     / "iOS"
                     / "Xcode"
                     / "First App"
@@ -305,7 +333,7 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
         ]
     )
     # The log is being tailed; no process cleanup has occurred
-    command.subprocess.Popen.assert_called_with(
+    command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -316,21 +344,30 @@ def test_run_app_simulator_shutting_down(first_app_config, tmp_path):
             "--style",
             "compact",
             "--predicate",
-            'senderImagePath ENDSWITH "/First App"',
+            'senderImagePath ENDSWITH "/First App"'
+            ' OR (processImagePath ENDSWITH "/First App"'
+            ' AND senderImagePath ENDSWITH "-iphonesimulator.so")',
         ],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.subprocess.stream_output.assert_called_with(
+    command.tools.subprocess.stream_output.assert_called_with(
+        "log stream", log_stream_process
+    )
+    command.tools.subprocess.cleanup.assert_called_with(
         "log stream", log_stream_process
     )
-    command.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
     """If the simulator fails to boot, raise an error."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -340,8 +377,8 @@ def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
     # Simulator is shut down
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
-    command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = subprocess.CalledProcessError(
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    command.tools.subprocess.run.side_effect = subprocess.CalledProcessError(
         cmd=["xcrun", "simclt", "boot", "..."], returncode=1
     )
 
@@ -350,7 +387,7 @@ def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
         command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -360,14 +397,19 @@ def test_run_app_simulator_boot_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.subprocess.Popen.assert_not_called()
-    command.subprocess.stream_output.assert_not_called()
-    command.subprocess.cleanup.assert_not_called()
+    command.tools.subprocess.Popen.assert_not_called()
+    command.tools.subprocess.stream_output.assert_not_called()
+    command.tools.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_open_failure(first_app_config, tmp_path):
     """If the simulator can't be opened, raise an error."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -378,11 +420,12 @@ def test_run_app_simulator_open_failure(first_app_config, tmp_path):
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot succeeds, but open fails.
-    command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = [
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    command.tools.subprocess.run.side_effect = [
         0,
         subprocess.CalledProcessError(
-            cmd=["open", "-a", "Simulator", "..."], returncode=1
+            cmd=["open", "-a", "Simulator", "..."],
+            returncode=1,
         ),
     ]
 
@@ -391,7 +434,7 @@ def test_run_app_simulator_open_failure(first_app_config, tmp_path):
         command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -413,14 +456,19 @@ def test_run_app_simulator_open_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.subprocess.Popen.assert_not_called()
-    command.subprocess.stream_output.assert_not_called()
-    command.subprocess.cleanup.assert_not_called()
+    command.tools.subprocess.Popen.assert_not_called()
+    command.tools.subprocess.stream_output.assert_not_called()
+    command.tools.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
     """If the old app can't be uninstalled, raise an error."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -431,8 +479,8 @@ def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator succeed, but uninstall fails.
-    command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = [
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    command.tools.subprocess.run.side_effect = [
         0,
         0,
         subprocess.CalledProcessError(
@@ -445,7 +493,7 @@ def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
         command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -478,14 +526,19 @@ def test_run_app_simulator_uninstall_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.subprocess.Popen.assert_not_called()
-    command.subprocess.stream_output.assert_not_called()
-    command.subprocess.cleanup.assert_not_called()
+    command.tools.subprocess.Popen.assert_not_called()
+    command.tools.subprocess.stream_output.assert_not_called()
+    command.tools.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_install_failure(first_app_config, tmp_path):
     """If the app fails to install in the simulator, raise an error."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -496,8 +549,8 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator, and uninstall succeed, but install fails.
-    command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = [
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    command.tools.subprocess.run.side_effect = [
         0,
         0,
         0,
@@ -511,7 +564,7 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
         command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -549,6 +602,7 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
                     "install",
                     "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D",
                     tmp_path
+                    / "base_path"
                     / "iOS"
                     / "Xcode"
                     / "First App"
@@ -561,14 +615,19 @@ def test_run_app_simulator_install_failure(first_app_config, tmp_path):
         ]
     )
     # The log will not be tailed
-    command.subprocess.Popen.assert_not_called()
-    command.subprocess.stream_output.assert_not_called()
-    command.subprocess.cleanup.assert_not_called()
+    command.tools.subprocess.Popen.assert_not_called()
+    command.tools.subprocess.stream_output.assert_not_called()
+    command.tools.subprocess.cleanup.assert_not_called()
 
 
 def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
     """If the app fails to launch, raise an error."""
-    command = iOSXcodeRunCommand(base_path=tmp_path)
+    command = iOSXcodeRunCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
 
     # A valid target device will be selected.
     command.select_target_device = mock.MagicMock(
@@ -579,8 +638,8 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
     command.get_device_state = mock.MagicMock(return_value=DeviceState.SHUTDOWN)
 
     # Call to boot and open simulator, uninstall and install succeed, but launch fails.
-    command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = [
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
+    command.tools.subprocess.run.side_effect = [
         0,
         0,
         0,
@@ -590,14 +649,14 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
         ),
     ]
     log_stream_process = mock.MagicMock()
-    command.subprocess.Popen.return_value = log_stream_process
+    command.tools.subprocess.Popen.return_value = log_stream_process
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
         command.run_app(first_app_config)
 
     # The correct sequence of commands was issued.
-    command.subprocess.run.assert_has_calls(
+    command.tools.subprocess.run.assert_has_calls(
         [
             # Boot the device
             mock.call(
@@ -635,6 +694,7 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
                     "install",
                     "2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D",
                     tmp_path
+                    / "base_path"
                     / "iOS"
                     / "Xcode"
                     / "First App"
@@ -658,7 +718,7 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
         ]
     )
     # The log stream process will have been started; but will not be tailed
-    command.subprocess.Popen.assert_called_with(
+    command.tools.subprocess.Popen.assert_called_with(
         [
             "xcrun",
             "simctl",
@@ -669,13 +729,17 @@ def test_run_app_simulator_launch_failure(first_app_config, tmp_path):
             "--style",
             "compact",
             "--predicate",
-            'senderImagePath ENDSWITH "/First App"',
+            'senderImagePath ENDSWITH "/First App"'
+            ' OR (processImagePath ENDSWITH "/First App"'
+            ' AND senderImagePath ENDSWITH "-iphonesimulator.so")',
         ],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         bufsize=1,
     )
-    command.subprocess.stream_output.assert_not_called()
+    command.tools.subprocess.stream_output.assert_not_called()
 
     # The log process was cleaned up.
-    command.subprocess.cleanup.assert_called_once_with("log stream", log_stream_process)
+    command.tools.subprocess.cleanup.assert_called_once_with(
+        "log stream", log_stream_process
+    )
